Skip to main content

rebotics_sdk

Rebotics SDK for communicating with Rebotics Services, API CLI client.

Features

  • Communication between Rebotics Services through provider client classes

  • Two django applications for external communications through web-hooks

  • CLI clients for Rebotics Services

Prerequisites

You need to have Python 3.7+ installed in your system for current system user.

Installation

Linux & MacOS

Can be installed with pip:

pip3 install --user --upgrade rebotics_sdk

You should have directory ~/.local/bin/ in your PATH variable in ~/.bashrc or ~/.bash_profile.

Windows

Is installed without –user flag:

pip install --upgrade rebotics_sdk

Open environment variable settings and find PATH variable.

After installation rebotics-scripts should be located inside python3 directory.

Append the following path %APPDATA%\Local\Python<version>\bin\ to PATH variable, then log out from your system or restart your PC.

CLI Installation

To run the commands in shell:

pip install --upgrade --quiet --no-input rebotics_sdk[shell]

Usage

After successful installation the CLI for following services should be accessible:

  • admin

  • dataset

  • retailer

  • rebm

  • rebotics

  • fvm

  • hawkeye

  • hawkeye_camera

The “role” could be configured for these services except rebotics and hawkeye_camera.

Retailer setup

For setup you need to configure role to access retailer instance with specifying retailer server:

retailer -r alpha configure --help

This command will prompt you to set retailer host, your username and password.

For role you can specify anything for your own convenience.

Retailer CLI client

Usage:

retailer [OPTIONS] COMMAND [ARGS]...

Options:

-f, --format [table|id|json]

-v, --verbose                 Enables verbose mode

-c, --config PATH             Specify what config.json to use

-r, --role TEXT               Key to specify what retailer to use

                              [required]

--api-verbosity INT           Display request detail

--version                     Show the version and exit.

--help                        Show this message and exit.

Note: The same CLI structure could be used for other services. Check the documentation on available commands at Confluence page.

Hawkeye Camera CLI client

Admin CLI tool to communicate with Public Hawkeye API for cameras without authorization does not require to configure role in rebotics_sdk. Instead, it accepts the target server url.

Example usage:

hawkeye_camera -h https://hawkeye.rebotics.net create-capture "path_to_image.jpg" -c "camera_token"

Credits

This package was created with Cookiecutter and the audreyr/cookiecutter-pypackage project template.

History

0.1.0 (2019-05-22)

  • First release on PyPI.

Metadata

Release files for rebotics-sdk 0.31.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for rebotics-sdk 0.31.1
File Size Uploaded
rebotics_sdk-0.31.1.tar.gz 21.5 MB Details

Built distribution (wheel)

Table of built distributions (wheels) for rebotics-sdk 0.31.1
File Interpreter ABI Platform
rebotics_sdk-0.31.1-py2.py3-none-any.whl Python 3, Python 2 none any Details

Total release size: 21.6 MB

Release files / rebotics_sdk-0.31.1.tar.gz

Download URL rebotics_sdk-0.31.1.tar.gz
Size 21.5 MB
Tags Source
SHA-256 checksum
How to use checksums
610a16bb0908e3c3bbf794d7a4f4851a9bfec4b59fa6af2adc4fe7528cbc1cd5
BLAKE2b-256 checksum
How to use checksums
5d202f93878e1a0d3a3a1dbf5210636047c47a2706a1b8468b5c2c03e1788b1b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.12.9

Release files / rebotics_sdk-0.31.1-py2.py3-none-any.whl

Download URL rebotics_sdk-0.31.1-py2.py3-none-any.whl
Size 106.1 kB
Tags Python 2 Python 3
SHA-256 checksum
How to use checksums
1452f78c1eec75746973f656de610c0fdefa92cb8c68b03682d851b949d4ec91
BLAKE2b-256 checksum
How to use checksums
c43c9375c4bc019860e5f84418150ecb6a8e2e06e3e5e0c1f91f5838a7a5db17
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.12.9

Release history Release notifications | RSS feed

This release

0.31.1 This release

2 release files

0.31.0

2 release files

0.30.5

2 release files

0.30.4

2 release files

0.30.3

2 release files

0.30.2

2 release files

0.30.0

2 release files

0.29.0

2 release files

0.28.5

2 release files

0.28.4

2 release files

0.28.3

2 release files

0.28.2

2 release files

0.28.0

2 release files

0.27.3

2 release files

0.27.2

2 release files

0.26.1

2 release files

0.26.0

2 release files

0.25.2

2 release files

0.25.1

2 release files

0.25.0

2 release files

0.24.0

2 release files

0.23.1

2 release files

0.22.0

2 release files

0.21.5

2 release files

0.21.4

2 release files

0.21.0

2 release files

0.20.1

2 release files

0.20.0

2 release files

0.19.0

2 release files

0.18.2

2 release files

0.18.1

2 release files

0.18.0

2 release files

0.17.8

2 release files

0.17.7

2 release files

0.17.6

2 release files

0.17.5

2 release files

0.17.4

2 release files

0.17.3

2 release files

0.17.2

2 release files

0.16.0

2 release files

0.15.3

2 release files

0.15.2

2 release files

0.15.1

2 release files

0.14.9

2 release files

0.14.8

2 release files

0.14.7

2 release files

0.14.6

2 release files

0.14.4

2 release files

0.14.3

2 release files

0.14.2

2 release files

0.14.0

2 release files

0.13.1

2 release files

0.12.2

2 release files

0.12.1

2 release files

0.12.0

2 release files

0.11.1

2 release files

0.11.0

2 release files

0.10.1

2 release files

0.10.0

2 release files

0.9.1

2 release files

0.9.0

2 release files

0.8.2

2 release files

0.8.0

2 release files

0.7.0

2 release files

0.6.2

2 release files

0.6.1

2 release files

0.6.0

2 release files

0.5.8

2 release files

0.5.7

2 release files

0.5.6

2 release files

0.5.5

2 release files

0.5.4

2 release files

0.5.3

2 release files

0.5.2

2 release files

0.5.1

2 release files

0.5.0

2 release files

0.4.5

2 release files

0.4.4

2 release files

0.4.3

2 release files

0.4.2

2 release files

0.4.1

2 release files

0.4.0

2 release files

0.3.11

2 release files

0.3.10

2 release files

0.3.9

2 release files

0.3.8

2 release files

0.3.7

2 release files

0.3.6

2 release files

0.3.5

2 release files

0.3.4

2 release files

0.3.3

2 release files

0.3.2

2 release files

0.3.1

2 release files

0.3.0

2 release files

0.2.10

2 release files

0.2.9

2 release files

0.2.8

2 release files

0.2.6

2 release files

0.2.5

2 release files

0.2.4

2 release files

0.2.3

2 release files

0.2.2

2 release files

0.2.1

2 release files

0.2.0

2 release files

0.1.10

2 release files

0.1.9

2 release files

0.1.8

2 release files

0.1.7

2 release files

0.1.6

2 release files

0.1.5

2 release files

0.1.4

2 release files

0.1.3

2 release files

0.1.2

2 release files

0.1.1

2 release files

0.1.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page